summaryrefslogtreecommitdiff
path: root/entry.S
diff options
context:
space:
mode:
Switch back bpmain back to main
Diffstat (limited to 'entry.S')
-rw-r--r--entry.S4
1 files changed, 2 insertions, 2 deletions
diff --git a/entry.S b/entry.S
index 88ad92b..2de4fc3 100644
--- a/entry.S
+++ b/entry.S
@@ -84,8 +84,8 @@ start64:
# Clear frame pointer for stack walks
movl $0, %ebp
# Call into C code.
- call bpmain
- # should not return from bpmain
+ call main
+ # should not return from main
jmp .
.code32